#[repr(u8)]pub enum Level {
Show 16 variants
Min = 0,
_RESERVED_1 = 1,
_RESERVED_2 = 2,
_RESERVED_3 = 3,
_RESERVED_4 = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
_RESERVED_8 = 8,
_RESERVED_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
Max = 15,
}Variants
Min = 0
Zero invasion. This setting has a greater risk of a FIFO overflow.
_RESERVED_1 = 1
_RESERVED_2 = 2
_RESERVED_3 = 3
_RESERVED_4 = 4
_RESERVED_5 = 5
_RESERVED_6 = 6
_RESERVED_7 = 7
_RESERVED_8 = 8
_RESERVED_9 = 9
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
Max = 15
Maximum invasion occurs but there is less risk of a FIFO overflow.
Implementations