#[repr(u8)]pub enum Sprel {
Enabled = 0,
_RESERVED_1 = 1,
DataOnly = 2,
Disabled = 3,
}Variants
Enabled = 0
The trace unit does not affect the tracing of SP-relative transfers.
_RESERVED_1 = 1
DataOnly = 2
The trace unit does not trace the address portion of SP-relative transfers. If data value tracing is enabled then the trace unit generates a P1 data address element.
Disabled = 3
The trace unit does not trace the address or value portions of SP-relative transfers.
Implementations